@@ -1,15 +1,81 @@
 use strict;
 use warnings;
 package HTML::Widget::Plugin::Select;
-{
-  $HTML::Widget::Plugin::Select::VERSION = '0.101';
-}
-use parent 'HTML::Widget::Plugin';
 # ABSTRACT: a widget for selection from a list
+$HTML::Widget::Plugin::Select::VERSION = '0.200';
+use parent 'HTML::Widget::Plugin';
 
+# =head1 SYNOPSIS
+#
+#   $widget_factory->select({
+#     id      => 'the-selector', # if no name attr given, defaults to id value
+#     value   => 10,
+#     options => [
+#       [  0 => "Zero" ],
+#       [  5 => "Five" ],
+#       [ 10 => "Ten"  ],
+#     ],
+#   });
+#
+# =head1 DESCRIPTION
+#
+# This plugin provides a select-from-list widget.
+#
+# The C<default_classes> attribute may be used to add a default class to every
+# produced input.  This class cannot be overridden.
+#
+#   my $plugin = HTML::Widget::Factory::Input->new({
+#     default_classes => [ qw(foo bar) ],
+#   });
+#
+# =head1 METHODS
+#
+# =head2 C< provided_widgets >
+#
+# This plugin provides the following widgets: select
+#
+# =cut
 
 sub provided_widgets { qw(select) }
 
+# =head2 C< select >
+#
+# This method returns a select-from-list widget.
+#
+# In addition to the generic L<HTML::Widget::Plugin> attributes, the following
+# are valid arguments:
+#
+# =over
+#
+# =item disabled
+#
+# If true, this option indicates that the select widget can't be changed by the
+# user.
+#
+# =item ignore_invalid
+#
+# If this is given and true, an invalid value is ignored instead of throwing an
+# exception.
+#
+# =item options
+#
+# This may be an arrayref of arrayrefs, each containing a value/name pair, or it
+# may be a hashref of values and names.
+#
+# Use the array form if you need multiple entries for a single value or if order
+# is important.
+#
+# =item value
+#
+# If this argument is given, the option with this value will be pre-selected in
+# the widget's initial state.
+#
+# An exception will be thrown if more or less than one of the provided options
+# has this value.
+#
+# =back
+#
+# =cut
 
 use HTML::Element;
 
@@ -22,6 +88,14 @@ sub select { ## no critic Builtin
   $self->build($factory, $arg);
 }
 
+# =head2 C< build >
+#
+#  my $widget = $class->build($factory, \%arg)
+#
+# This method does the actual construction of the widget based on the args set up
+# in the exported widget-constructing call.  It's here for subclasses to exploit.
+#
+# =cut
 
 sub build {
   my ($self, $factory, $arg) = @_;
@@ -50,6 +124,15 @@ sub build {
   return $widget->as_XML;
 }
 
+# =head2 C< make_option >
+#
+#   my $option = $class->make_option($factory, $value, $name, $arg);
+#
+# This method constructs the HTML::Element option element that will represent one
+# of the options that may be put into the select box.  This is here for
+# subclasses to exploit.
+#
+# =cut
 
 sub make_option {
   my ($self, $factory, $value, $name, $arg) = @_;
@@ -62,6 +145,12 @@ sub make_option {
   return $option;
 }
 
+# =head2 C< validate_value >
+#
+# This method checks whether the given value option is valid.  See C<L</select>>
+# for an explanation of its default rules.
+#
+# =cut
 
 sub validate_value {
   my ($class, $value, $options) = @_;
@@ -80,19 +169,37 @@ sub validate_value {
   }
 }
 
+sub rewrite_arg {
+  my ($self, $arg) = @_;
+
+  $arg = $self->SUPER::rewrite_arg($arg);
+
+  if ($self->{default_classes}) {
+    my $class = join q{ }, @{ $self->{default_classes} };
+    $arg->{attr}{class} = defined $arg->{attr}{class}
+      ? "$class $arg->{attr}{class}"
+      : $class;
+  }
+
+  return $arg;
+}
+
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::Widget::Plugin::Select - a widget for selection from a list
 
 =head1 VERSION
 
-version 0.101
+version 0.200
 
 =head1 SYNOPSIS
 
@@ -110,6 +217,13 @@ version 0.101
 
 This plugin provides a select-from-list widget.
 
+The C<default_classes> attribute may be used to add a default class to every
+produced input.  This class cannot be overridden.
+
+  my $plugin = HTML::Widget::Factory::Input->new({
+    default_classes => [ qw(foo bar) ],
+  });
+
 =head1 METHODS
 
 =head2 C< provided_widgets >
